/// Extensions

//// Install extensions automatically
// Only from the current user's profile.
// https://extensionworkshop.com/documentation/enterprise/enterprise-distribution/#controlling-automatic-installations
user_pref("extensions.autoDisableScopes", 14);
